@@ -107,6 +107,7 @@ namespace code {
 	 * Create instructions:
 	 */
 
+	Instr *STORM_FN nop(EnginePtr e);
 	Instr *STORM_FN mov(EnginePtr e, Operand to, Operand from);
 	Instr *STORM_FN swap(EnginePtr e, Reg a, Operand b);
 	Instr *STORM_FN jmp(EnginePtr e, Operand to);
@@ -214,9 +215,12 @@ namespace code {
 	Instr *STORM_FN prolog(EnginePtr e);
 	Instr *STORM_FN epilog(EnginePtr e);
 
-	// Note that a register has been preserved on the stack.
+	// Note that a register has been preserved on the stack. Intended to be used internally by backends.
 	Instr *STORM_FN preserve(EnginePtr e, Operand dest, Reg reg);
 
+	// Note that a register has been preserved by pushing it. Intended to be used internally by backends.
+	Instr *STORM_FN preserve(EnginePtr e, Reg reg);
+
 	// Node a source position.
 	Instr *STORM_FN location(EnginePtr e, SrcPos pos);
 
