@@ -27,11 +27,14 @@ namespace code {
 		// Used by the backends: What is stored in the variable is actually a pointer to the value.
 		STORM_NAME(freeIndirection, indirection) = 0x20,
 
+		// Used by the backends: Do not initialize this variable.
+		STORM_NAME(freeNoInit, noInit) = 0x40,
+
 		// Default options.
 		STORM_NAME(freeDef, default) = freeOnBoth,
 
 		// This variable needs to be activated before it will be freed.
-		STORM_NAME(freeInactive, inactive) = 0x40,
+		STORM_NAME(freeInactive, inactive) = 0x80,
 	};
 
 	BITMASK_OPERATORS(FreeOpt);
@@ -116,6 +119,9 @@ namespace code {
 		inline Instr *STORM_FN operator [](Nat id) const { return at(id); }
 		inline Instr *at(Nat id) const { return code->at(id).instr; }
 
+		// Modify instruction (internal use).
+		inline void setInstr(Nat id, Instr *to) { code->at(id).instr = to; }
+
 		// Give 'id = count()' to access any labels after the last instruction.
 		MAYBE(Array<Label> *) STORM_FN labels(Nat id) const;
 
@@ -425,6 +431,10 @@ namespace code {
 
 	StrBuf &STORM_FN operator <<(StrBuf &to, Listing::Entry e);
 
+	// Insert a nop instruction if the last instruction was a call instruction.
+	// This is needed on some backends because the function return addresses are
+	// otherwise treated as if the next instruction faulted and is to be re-tried.
+	void STORM_FN padCallWithNop(Listing *dest);
 }
 
 #include "InstrFwd.h"
