@@ -29,7 +29,7 @@ namespace storm {
 					throw new (this) SyntaxError(pos, msg);
 				}
 
-				if (!expected.canStore(params->at(1).type())) {
+				if (!expected.mayReferTo(params->at(1).type())) {
 					Str *msg = TO_S(engine(), S("This constructor needs to take a ")
 									<< expected << S(" as the first parameter, not " << params->at(1)));
 					throw new (this) SyntaxError(pos, msg);
@@ -307,10 +307,10 @@ namespace storm {
 			if (hiddenThread) {
 				actuals->push(params->code(0, s, ctor->params->at(0), block->scope));
 				actuals->push(block->threadParam->var.v);
-				for (nat i = 2; i < values->params->count(); i++)
+				for (Nat i = 2; i < values->params->count(); i++)
 					actuals->push(params->code(i - 1, s, ctor->params->at(i), block->scope));
 			} else {
-				for (nat i = 0; i < values->params->count(); i++)
+				for (Nat i = 0; i < values->params->count(); i++)
 					actuals->push(params->code(i, s, ctor->params->at(i), block->scope));
 			}
 
@@ -531,9 +531,13 @@ namespace storm {
 				throw new (this) SyntaxError(pos, msg);
 			}
 
-			if (t.isPrimitive()) {
-				// Default value is already there.
+			if (v->initializer) {
+				// If an initializer was specified, use that.
+				initVarInitializer(s, v);
+			} else if (t.isPrimitive()) {
+				// Primitives don't need initialization since we zero memory by default.
 			} else if (t.isValue()) {
+				// Values:
 				Function *ctor = t.type->defaultCtor();
 				if (!ctor) {
 					Str *msg = TO_S(engine(), S("Can not initialize ") << v->name << S(" by default-constructing it. ")
@@ -546,6 +550,7 @@ namespace storm {
 				*s->l << fnParam(engine().ptrDesc(), ptrA);
 				*s->l << fnCall(ctor->ref(), false);
 			} else {
+				// Classes:
 				Function *ctor = t.type->defaultCtor();
 				if (!ctor) {
 					Str *msg = TO_S(engine(), S("Can not initialize ") << v->name << S(" by default-constructing it. ")
@@ -563,6 +568,23 @@ namespace storm {
 			}
 		}
 
+		void InitBlock::initVarInitializer(CodeGen *s, MemberVar *v) {
+			using namespace code;
+
+			assert(v->initializer);
+
+			code::Var dest = thisVar->var.v;
+			code::Var resultPtr = s->l->createVar(s->block, Size::sPtr);
+
+			// Make a result pointer to pass to the function call.
+			*s->l << mov(ptrA, dest);
+			*s->l << add(ptrA, ptrConst(v->offset()));
+			*s->l << mov(resultPtr, ptrA);
+
+			// Call the function.
+			v->initializer->autoCallRef(s, new (this) Array<code::Operand>(), resultPtr);
+		}
+
 		void InitBlock::initVar(CodeGen *s, MemberVar *v, Initializer *to) {
 			using namespace code;
 
@@ -655,5 +677,73 @@ namespace storm {
 			*s->l << mov(ptrRel(ptrA, v->offset()), loc);
 		}
 
+
+		DelegateCall::DelegateCall(SrcPos pos, CtorBody *block, Actuals *params) : Expr(pos), block(block), params(params) {
+			if (block->superCalled || block->initDone) {
+				throw new (this) SyntaxError(pos, S("It is not possible to use 'self' together with either 'super'")
+											S(" or 'init' constructs in the constructor."));
+			}
+			block->superCalled = true;
+			block->initDone = true;
+
+			// Look at the hidden "this" parameter.
+			thisVar = block->variable(new (this) SimplePart(S(" this")));
+			thisPtr = thisVar->result;
+
+			// Add the regular "this" parameter for the remainder of the constructor.
+			LocalVar *created = new (this) ThisVar(thisPtr, thisVar->pos, true);
+			created->constant = true;
+			block->add(created);
+
+			// Update 'params'.
+			this->params->addFirst(new (this) LocalVarAccess(pos, thisVar));
+		}
+
+		ExprResult DelegateCall::result() {
+			return ExprResult();
+		}
+
+		void DelegateCall::code(CodeGen *s, CodeResult *r) {
+			RunOn runOn = thisPtr.type->runOn();
+			bool hiddenThread = runOn.state == RunOn::runtime;
+
+			// Find something to call.
+			BSNamePart *values = new (this) BSNamePart(Type::CTOR, pos, params);
+
+			if (hiddenThread)
+				values->insert(storm::thisPtr(Thread::stormType(engine())), 1);
+
+			Function *ctor = as<Function>(thisPtr.type->find(values, block->scope));
+			if (!ctor) {
+				Str *msg = TO_S(engine(), S("No constructor (") << values
+								<< S(") found in ") << thisPtr.type->identifier() << S("."));
+				throw new (this) SyntaxError(pos, msg);
+			}
+
+			Array<code::Operand> *actuals = new (this) Array<code::Operand>();
+			actuals->reserve(values->params->count());
+
+			if (hiddenThread) {
+				actuals->push(params->code(0, s, ctor->params->at(0), block->scope));
+				actuals->push(block->threadParam->var.v);
+				for (Nat i = 2; i < values->params->count(); i++)
+					actuals->push(params->code(i - 1, s, ctor->params->at(i), block->scope));
+			} else {
+				for (Nat i = 0; i < values->params->count(); i++)
+					actuals->push(params->code(i, s, ctor->params->at(i), block->scope));
+			}
+
+			CodeResult *t = new (this) CodeResult();
+			ctor->localCall(s, actuals, t, false);
+		}
+
+		void DelegateCall::toS(StrBuf *to) const {
+			*to << S("self") << params;
+		}
+
+		Bool DelegateCall::isolate() {
+			return false;
+		}
+
 	}
 }
