@@ -96,7 +96,9 @@ namespace storm {
 			BlockLookup *lookup = as<BlockLookup>(scope.top);
 			if (!lookup)
 				throw new (this) InternalError(S("Can not use FnCall::name() without having a scope referring to a block."));
-			return new (this) UnresolvedName(lookup->block, toExecute->path(), pos, params, false);
+			SimpleName *path = toExecute->path();
+			path->last()->params = new (this) Array<Value>();
+			return new (this) UnresolvedName(lookup->block, path, pos, params, false);
 		}
 
 		void FnCall::makeAsync() {
@@ -118,7 +120,7 @@ namespace storm {
 
 			// Note that toExecute->params may not be equal to params->values()
 			// since some actual parameters may report that they can return a
-			// reference to a value. However, we know that toExecute->params.canStore(params->values())
+			// reference to a value. However, we know that toExecute->params.mayReferTo(params->values())
 			// so it is OK to take toExecute->params directly.
 			Array<Value> *values = toExecute->params;
 			Array<code::Operand> *vars = new (this) Array<code::Operand>(values->count());
