@@ -276,13 +276,13 @@ namespace storm {
 					if (!updated[type.super])
 						continue;
 
-					into->types[i]->setSuper(into->types[type.super]);
+					into->types[i]->setSuper(into->types[Nat(type.super)]);
 					break;
 				case CppType::tSuperThread:
 					if (TObject::stormType(*e) == null)
 						continue;
 
-					into->types[i]->setThread(into->namedThreads[type.super]);
+					into->types[i]->setThread(into->namedThreads[Nat(type.super)]);
 					break;
 				case CppType::tCustom:
 				case CppType::tEnum:
@@ -329,14 +329,14 @@ namespace storm {
 
 			for (Nat i = 0; i < entries; i++) {
 				// Uncheckable?
-				if (ref.offsets[i] == size_t(-1))
+				if (ref.offsets[i] == nat(-1))
 					continue;
 
 				assert(t->offset[i] == ref.offsets[i], L"Type offset mismatch for " + ::toS(type.name) + L" member #" +
 					::toS(i) + L". Storm offset: " + ::toS(t->offset[i]) + L", C++ offset: " + ::toS(ref.offsets[i]));
 			}
 
-			assert(ref.offsets[entries] == size_t(-1), L"There is more data for " + ::toS(type.name));
+			assert(ref.offsets[entries] == nat(-1), L"There is more data for " + ::toS(type.name));
 		}
 #endif
 
