@@ -216,6 +216,7 @@ namespace storm {
 		// to compile some destructors during shutdown...
 		gc.collect();
 
+		advance(bootLateShutdown);
 		// We need to remove the root this array implies before the Gc is destroyed.
 		world.clear();
 
@@ -611,6 +612,12 @@ namespace storm {
 		return o.root;
 	}
 
+	Package *Engine::corePackage() {
+		if (!o.corePkg)
+			o.corePkg = package(S("core"));
+		return o.corePkg;
+	}
+
 	Package *Engine::package(SimpleName *name, bool create) {
 		Package *now = package();
 
