@@ -195,7 +195,7 @@ namespace storm {
 
 	void Type::makeType(Engine &e, GcType *src) {
 		// Find the entry containing OFFSET_OF(Type, myGcType).
-		nat myTypePos = src->count;
+		nat myTypePos = Nat(src->count);
 		for (nat i = 0; i < src->count; i++) {
 			if (src->offset[i] == OFFSET_OF(Type, myGcType)) {
 				myTypePos = i;
@@ -994,6 +994,9 @@ namespace storm {
 	}
 
 	void Type::buildHandle() {
+		// Note: It seems that for pure C++ types, we replace the handle that was generated from
+		// C++. We could skip doing that in many situations? For example, this happens during boot
+		// for NameSet lookups, when Str::hash is loaded, for example.
 		bool val = value();
 
 		if (!val) {
