@@ -157,7 +157,7 @@ namespace storm {
 		GcWatch *watch;
 
 		// Our capacity.
-		inline nat capacity() const { return info ? info->count : 0; }
+		inline nat capacity() const { return info ? (nat)info->count : 0; }
 
 		// Get locations for keys or values.
 		inline void *keyPtr(nat id) { return key->v + id*keyT.size; }
@@ -171,6 +171,9 @@ namespace storm {
 		// Allocate data for a specific capacity. Assumes 'info', 'key' and 'value' are null.
 		void alloc(nat capacity);
 
+		// Allocate data, assumes we are rehashing.
+		void allocRehash(nat capacity);
+
 		// Grow (if needed) to fit at least one more element.
 		void grow();
 
