@@ -132,7 +132,7 @@ namespace storm {
 		GcWatch *watch;
 
 		// Our capacity.
-		inline nat capacity() const { return info ? info->count : 0; }
+		inline nat capacity() const { return info ? nat(info->count) : 0; }
 
 		// Get locations for keys or values.
 		inline void *keyPtr(nat id) { return key->v + id*keyT.size; }
@@ -143,6 +143,9 @@ namespace storm {
 		// Allocate data for a specific capacity. Assumes 'info', 'key' and 'value' are null.
 		void alloc(nat capacity);
 
+		// Allocate data for capacity, assumes we are re-hashing.
+		void allocRehash(nat capacity);
+
 		// Grow (if needed) to fit at least one more element.
 		void grow();
 
