@@ -95,6 +95,11 @@ namespace gui {
 		// is the notification code specified by the message (eg BN_CLICK).
 		virtual bool onCommand(nat type);
 
+		// Called when a WM_NOTIFY has been sent to (by) us. Return 'true' if it is handled. The
+		// parameter is the header for notify as sent in the message. This can be casted to a
+		// relevant struct to receive more information.
+		virtual bool onNotify(NMHDR *data);
+
 		// Get the current DPI for this window. Only makes sense on Windows.
 		virtual Nat currentDpi();
 
@@ -145,6 +150,9 @@ namespace gui {
 		// Called when the window is resized.
 		virtual void STORM_FN resized(Size size);
 
+		// Convenience function to trigger uptade of layouts easily.
+		void STORM_FN resized();
+
 		// Key events. Return 'true' if the message was handled and should not propagate further.
 		virtual Bool STORM_FN onKey(Bool pressed, key::Key keycode, mod::Modifiers modifiers);
 		virtual Bool STORM_FN onChar(Nat charCode);
@@ -249,6 +257,10 @@ namespace gui {
 		// Painter.
 		Painter *myPainter;
 
+		// Last allocated width and height. Used to filter out duplicate allocate messages.
+		int lastWidth;
+		int lastHeight;
+
 		// In Gtk+, widgets are usually not rendered in separate windows. When we're using OpenGL
 		// rendering, we need separate windows for the widget being drawn to, and any child
 		// widgets. This variable represents the created window.
